// Copyright (c) 2002 Andreas Jnsson, www.AngelCode.com

#include <windows.h>
#include "resource.h"
#include "overlay.h"
#include "image.h"
#include "desktop.h"

// The animation update interval (in milliseconds)
#define  DELTATIME   50

// Function prototype
INT_PTR CALLBACK DialogProc(HWND, UINT, WPARAM, LPARAM);

//-------------------------------------------------------------------

int WINAPI WinMain(HINSTANCE hInst, HINSTANCE, LPSTR, int)
{
	// Initialize the image we'll show on the overlay surface.
	// This will avoid uninitialized memory noise on the surface.
	InitImage();	

	// Initialize the overlay surface
	if( InitOverlay() < 0 )
		return 0;

	// Set the desktop background to the color of the dest color key
	SetDesktopColor(COLORKEY);

	// Show a modal dialog box. When the dialog box is closed 
	// by the user this function returns control to us.
	DialogBox(hInst, MAKEINTRESOURCE(IDD_QUITDIALOG), 0, (DLGPROC)DialogProc);

	// Restore the desktop background
	RestoreDesktop();

	// Remove the overlay
	UninitOverlay();

	return 0;
}

//-------------------------------------------------------------------

// Our dialog procedure
INT_PTR CALLBACK DialogProc(HWND hWnd, UINT message, WPARAM wParam, LPARAM lParam)
{
	switch (message) 
	{
	case WM_INITDIALOG:
		{
			// Set the application icons
			HICON icon = (HICON)LoadImage(GetModuleHandle(0), MAKEINTRESOURCE(IDI_ICON), IMAGE_ICON, 0, 0, LR_DEFAULTSIZE|LR_SHARED);
			SendMessage(hWnd, WM_SETICON, ICON_BIG, (LPARAM)icon);
			icon = (HICON)LoadImage(GetModuleHandle(0), MAKEINTRESOURCE(IDI_ICON), IMAGE_ICON, 16, 16, LR_SHARED);
			SendMessage(hWnd, WM_SETICON, ICON_SMALL, (LPARAM)icon);

			// Create a timer so that we can animate our drawing
			SetTimer(hWnd, 1, DELTATIME, 0);
		}
		return TRUE;

	case WM_COMMAND:
		// Close the window no matter what command it is

	case WM_CLOSE:
		// Destroy the window
		DestroyWindow(hWnd);
		return TRUE;

	case WM_DESTROY:
		// Kill our timer
		KillTimer(hWnd, 1);

		// Post the quit message so that our main loop will know that we have quit
		PostQuitMessage(0);
		return TRUE;

	case WM_TIMER:
		// Animate the image
		UpdateImage();

		// Show the new frame
		UpdateOverlay();
		return TRUE;
    }

    return FALSE;
}

